Learn R Programming

EpiSignalDetection (version 0.1.3)

aggAtlasExport: Aggregate filtered final Atlas export

Description

Aggregate filtered final Atlas export

Usage

aggAtlasExport(x, input)

Value

dataframe aggregated by geographical level and time unit

Arguments

x

dataframe

input

list of parameters as defined in the Signal Detection Application (see runEpiSDApp)

(i.e. list(disease, country, indicator, stratification, unit, daterange, algo, testingperiod))

See Also

filterAtlasExport SignalData stsSD

Examples

Run this code
#-- Setting the parameters to run the report for
input <- list(
disease = "Salmonellosis",
country = "EU-EEA - complete series",
indicator = "Reported cases",
stratification = "Confirmed cases",
unit = "Month",
daterange = c("2010-01-01", "2016-12-31"),
algo = "FarringtonFlexible",
testingperiod = 5
)

#-- Example dataset
dataset <- EpiSignalDetection::SignalData

#-- Filtering on declared input parameters
dataset <- filterAtlasExport(dataset, input)

#-- Aggregating the data by geographical level and time point
dataset <- aggAtlasExport(dataset, input)

Run the code above in your browser using DataLab