Learn R Programming

EpiSignalDetection (version 0.1.3)

cleanAtlasExport: Clean the Atlas export dataframe

Description

Clean the Atlas data export dataframe before signal detection analysis
(see importAtlasExport and online ECDC Atlas: https://atlas.ecdc.europa.eu/public/index.aspx)

Usage

cleanAtlasExport(x)

Value

dataframe

Arguments

x

dataframe, usually the ouput of the import function importAtlasExport(x)

Details

The function will:

  • Filter only on case based indicators i.e. 'Reported Cases"

  • Create four additional time variables to ease the analysis:
    TimeUnit ('Year', 'Month', 'Week'),
    TimeYear (xxxx),
    TimeMonth (xx)
    TimeWeek(xx)

  • Keep only variables of interest i.e. "HealthTopic", "Population", "Time", "RegionName", "NumValue"

See Also

importAtlasExport filterAtlasExport

Examples

Run this code
if (FALSE) {
dataset <- cleanAtlasExport( importAtlasExport(x = 'ECDC_surveillance_data_Anthrax.csv') )
}


Run the code above in your browser using DataLab