Learn R Programming

EpiSignalDetection (version 0.1.2)

plotSD: Plot the Signal Detection time series

Description

Plot the Signal Detection time series including historical data, alarm detection period and alarms

Usage

plotSD(x, input, subRegionName, x.sts, x.algo)

Value

plot

Arguments

x

dataframe (default SignalData)

input

list of parameters as defined in the Signal Detection Application (see runEpiSDApp)

(i.e. list(disease, country, indicator, stratification, unit, daterange, algo, testingperiod))

subRegionName

character string, region label to use in the plot, if different than input$RegionName (optional)

x.sts

sts object (optional), see stsSD)

x.algo

algo object (optional), see algoSD)

See Also

SignalData runEpiSDApp

Examples

Run this code
#-- Setting the parameters to run the report for
input <- list(
disease = "Salmonellosis",
country = "EU-EEA - complete series",
indicator = "Reported cases",
stratification = "Confirmed cases",
unit = "Month",
daterange = c("2010-01-01", "2016-12-31"),
algo = "FarringtonFlexible",
testingperiod = 5
)

#-- Plotting the signal detection output
plotSD(input = input)

Run the code above in your browser using DataLab