runEpiSDApp: Run the EpiSignalDectection 'shiny' application

View source: R/runEpiSDApp.R

runEpiSDAppR Documentation

Run the EpiSignalDectection 'shiny' application

Description

Run the 'shiny' interactive application for signal detection analysis using ECDC Atlas export data.

Usage

runEpiSDApp()

Details

Datasets to use in the tool:

  • Default dataset included in the application (Salmonellosis 2007-2016 or Measles 1999-2018 data);

  • External dataset using the "Browse" button in the application:

    • –> An export (csv format) from the ECDC Surveillance Atlas of Infectious Diseases: https://atlas.ecdc.europa.eu/public/index.aspx.

      On the ECDC "Surveillance Atlas of Infectious Diseases" web site:

      • 1- Choose the disease/health topic to analyse

      • 2- Export the data (csv) using the default settings

      • 3- Import the csv in the application

      • 4- You can now explore the disease time series for signal detection...

    • –> Any dataset specified as described in the package vignette.

Examples

## Not run: 
# --- Run the 'shiny' app
# --- (NB: please open the app in an external browser
# --- in order to facilitate its use)
runEpiSDApp()

## End(Not run)


EpiSignalDetection documentation built on March 3, 2026, 5:07 p.m.