Learn R Programming

EpiSignalDetection (version 0.1.3)

studyPeriod: Compute the study period

Description

Compute a dataframe including two types of dates corresponding to the study period defined in the list of parameters input
(i.e. StudyPeriod = approximated daily date; Time = exact date in the format according to the time unit parameter)

Usage

studyPeriod(input)

Value

Dataframe including the complete time series with no gaps:

StudyPeriod

approximated daily date e.g. 2010-01-01

Time

exact date in the format according to the time unit parameter e.g. 2010-01

Arguments

input

list of parameters as defined in the Signal Detection Application (see runEpiSDApp)

(i.e. list(disease, country, indicator, stratification, unit, daterange, algo, testingperiod))

Examples

Run this code
#-- Setting the parameters to run the report for
input <- list(
disease = "Salmonellosis",
country = "EU-EEA - complete series",
indicator = "Reported cases",
stratification = "Confirmed cases",
unit = "Month",
daterange = c("2010-01-01", "2016-12-31"),
algo = "FarringtonFlexible",
testingperiod = 5
)

StudyPeriod <- studyPeriod(input)
head(StudyPeriod)

Run the code above in your browser using DataLab